LIFEsim
=======

LIFEsim is the simulator software for the Large Interferometer For Exoplanets (LIFE). It simulates
the interferometric measurement of LIFE to demonstrate the capabilities of the observatory. Coupled
with on-sky source simulations, LIFEsim will infer the amount and diversity of exoplanets
observable with LIFE. Inputting spectral information of exoplanets allows for a description of the
spectral measurement potential of LIFE.

Documentation
-------------

The LIFEsim documentation can be found here:
`https://lifesim.readthedocs.io/ <https://lifesim.readthedocs.io/>`_


Web Site
--------

Please visit the `LIFE website <https://www.life-space-mission.com/>`_  to learn more about the
LIFE mission.


Attribution
-----------

If you use LIFEsim in your work, please cite Ottiger et al., 2021.


License
-------

Copyright 2019-2020 Felix Dannert, Maurice Ottiger, Sascha Quanz and contributors.

LIFEsim is distributed under the GNU General Public License v3. See the LICENSE file for the terms
and conditions.
